Django Google Chrome Frame — django-gcframe v0.9.0 documentation

### Navigation

- index
- modules |
- next |
- django-gcframe v0.9.0 documentation »

# Django Google Chrome Frame

## Overview

`django-gcframe` is a set of Django utilities for working with Google Chrome Frame.

Specifically, the package provides configurable middleware and decorators for adding and removing the `X-UA-Compatible` HTTP haeder in view responses. Said header conditionally activates Google Chrome Frame when installed on Microsoft Internet Explorer, and conditionally enables a compatibility mode when GCF is not activated.

This package does not install Google Chrome Frame, though in the future it may have features that would promote installation.

## Contents

- Getting Started
  - Overview
  - Requirements
  - Installation & Usage
  - Support
- Middleware
  - Overview
  - Installation
- Decorators
  - Overview
  - gcframe
  - gcframe_exempt
- Configurable Settings
  - Overview
  - List of Settings

## Indices, etc.

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- django-gcframe v0.9.0 documentation »